# JobRunStatusDto


## Enum

* `FAILED` (value: `'failed'`)

* `PASSED` (value: `'passed'`)

* `CANCELLED` (value: `'cancelled'`)

* `UNKNOWN` (value: `'unknown'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


